@@ -58,7 +58,6 @@ ac_table = {
             '--extra-search-paths',
             '--timeout-ctrl',
             '--k8s-namespace',
-            '--k8s-disable-connection-pool',
             '--polling',
             '--uses',
             '--uses-with',
@@ -92,6 +91,7 @@ ac_table = {
             '--install-requirements',
             '--force-update',
             '--force',
+            '--compression',
             '--uses-before-address',
             '--uses-after-address',
             '--connection-list',
@@ -108,7 +108,6 @@ ac_table = {
             '--extra-search-paths',
             '--timeout-ctrl',
             '--k8s-namespace',
-            '--k8s-disable-connection-pool',
             '--polling',
             '--expose-graphql-endpoint',
             '--uses',
@@ -128,7 +127,6 @@ ac_table = {
             '--extra-search-paths',
             '--timeout-ctrl',
             '--k8s-namespace',
-            '--k8s-disable-connection-pool',
             '--polling',
             '--uses',
             '--uses-with',
@@ -156,6 +154,7 @@ ac_table = {
             '--graph-description',
             '--graph-conditions',
             '--deployments-addresses',
+            '--compression',
             '--runtime-backend',
             '--runtime',
             '--runtime-cls',
@@ -214,7 +213,6 @@ ac_table = {
             '--extra-search-paths',
             '--timeout-ctrl',
             '--k8s-namespace',
-            '--k8s-disable-connection-pool',
             '--polling',
             '--uses',
             '--uses-with',
@@ -248,6 +246,7 @@ ac_table = {
             '--install-requirements',
             '--force-update',
             '--force',
+            '--compression',
             '--uses-before-address',
             '--uses-after-address',
             '--connection-list',
@@ -264,7 +263,6 @@ ac_table = {
             '--extra-search-paths',
             '--timeout-ctrl',
             '--k8s-namespace',
-            '--k8s-disable-connection-pool',
             '--polling',
             '--uses',
             '--uses-with',
@@ -298,6 +296,7 @@ ac_table = {
             '--install-requirements',
             '--force-update',
             '--force',
+            '--compression',
             '--uses-before-address',
             '--uses-after-address',
             '--connection-list',
@@ -313,6 +312,7 @@ ac_table = {
             '--host',
             '--proxy',
             '--port',
+            '--tls',
             '--https',
             '--asyncio',
             '--return-responses',
