@@ -4,6 +4,7 @@ import asyncio
 from copy import deepcopy
 from platform import uname
 from http import HTTPStatus
+from abc import ABC, abstractmethod
 from typing import Dict, TYPE_CHECKING, List, Optional, Union
 
 import aiohttp
@@ -11,17 +12,13 @@ import aiohttp
 from jina import __docker_host__
 from jina.helper import colored, random_port
 from jina.enums import RemoteWorkspaceState
-from .base import BaseStore
-from ..dockerize import Dockerizer
-from ..excepts import (
-    PartialDaemon400Exception,
-    PartialDaemonConnectionException,
-)
-from ..helper import if_alive, id_cleaner, error_msg_from
-from ..models import DaemonID
-from ..models.ports import PortMappings
-from ..models.enums import UpdateOperation, IDLiterals
-from ..models.containers import (
+from daemon.stores.base import BaseStore
+from daemon.dockerize import Dockerizer
+from daemon.excepts import PartialDaemon400Exception, PartialDaemonConnectionException
+from daemon.helper import id_cleaner
+from daemon.models import DaemonID
+from daemon.models.ports import PortMappings
+from daemon.models.containers import (
     ContainerArguments,
     ContainerItem,
     ContainerMetadata,
@@ -32,45 +29,26 @@ if TYPE_CHECKING:
     from pydantic import BaseModel
 
 
-class ContainerStore(BaseStore):
+class ContainerStore(BaseStore, ABC):
     """A Store of Containers spawned by daemon"""
 
     _kind = 'container'
     _status_model = ContainerStoreStatus
+    _exposed_ports = set()
 
-    async def _add(self, uri, *args, **kwargs):
+    @abstractmethod
+    async def add_in_partial(self, uri, envs, *args, **kwargs):
         """Implements jina object creation in `partial-daemon`
 
         .. #noqa: DAR101"""
-        raise NotImplementedError
+        ...
 
-    @if_alive
-    async def _update(self, uri: str, params: Dict, **kwargs) -> Dict:
-        """Sends `PUT` request to `partial-daemon` to execute a command on a Flow.
-
-        :param uri: uri of partial-daemon
-        :param params: json payload to be sent
-        :param kwargs: keyword args
-        :raises PartialDaemon400Exception: if update fails
-        :return: response from partial-daemon
-        """
-
-        self._logger.debug(
-            f'sending PUT request to partial-daemon on {uri}/{self._kind}'
-        )
-        async with aiohttp.request(
-            method='PUT', url=f'{uri}/{self._kind}', params=params
-        ) as response:
-            response_json = await response.json()
-            if response.status != HTTPStatus.OK:
-                raise PartialDaemon400Exception(error_msg_from(response_json))
-            return response_json
-
-    async def _delete(self, uri, *args, **kwargs):
+    @abstractmethod
+    async def delete_in_partial(self, uri, *args, **kwargs):
         """Implements jina object termination in `partial-daemon`
 
         .. #noqa: DAR101"""
-        raise NotImplementedError
+        ...
 
     async def ready(self, uri) -> bool:
         """Check if the container with partial-daemon is alive
@@ -78,7 +56,7 @@ class ContainerStore(BaseStore):
         :param uri: uri of partial-daemon
         :return: True if partial-daemon is ready"""
         async with aiohttp.ClientSession() as session:
-            for _ in range(20):
+            for _ in range(60):
                 try:
                     async with session.get(uri) as response:
                         if response.status == HTTPStatus.OK:
@@ -94,7 +72,7 @@ class ContainerStore(BaseStore):
                         f'error while checking if partial-daemon is ready: {e}'
                     )
         self._logger.error(
-            f'couldn\'t reach {self._kind.title()} container at {uri} after 10secs'
+            f'couldn\'t reach {self._kind.title()} container at {uri} after 30secs'
         )
         return False
 
@@ -157,8 +135,10 @@ class ContainerStore(BaseStore):
         :raises PartialDaemonConnectionException: if jinad cannot connect to partial
         :return: id of the container
         """
+        container = None
+
         try:
-            from . import workspace_store
+            from daemon.stores import workspace_store
 
             if workspace_id not in workspace_store:
                 raise KeyError(f'{workspace_id} not found in workspace store')
@@ -167,10 +147,13 @@ class ContainerStore(BaseStore):
                     f'{workspace_id} is not ACTIVE yet. Please retry once it becomes ACTIVE'
                 )
 
-            partiald_port = random_port()
             dockerports = (
                 ports.docker_ports if isinstance(ports, PortMappings) else ports
             )
+            with self._lock:
+                for port in dockerports.values():
+                    self._exposed_ports.add(port)
+                partiald_port = self._find_partiald_port()
             dockerports.update({f'{partiald_port}/tcp': partiald_port})
             uri = self._uri(partiald_port)
             entrypoint = self._entrypoint(partiald_port, workspace_id)
@@ -198,25 +181,26 @@ class ContainerStore(BaseStore):
             )
             if not await self.ready(uri):
                 raise PartialDaemonConnectionException(
-                    f'{id.type.title()} creation failed, couldn\'t reach the container at {uri} after 10secs'
+                    f'{id.type.title()} creation failed, couldn\'t reach the container at {uri} after 30secs'
                 )
             kwargs.update(
                 {'ports': ports.dict()} if isinstance(ports, PortMappings) else {}
             )
-            object = await self._add(uri=uri, params=params, **kwargs)
+            object = await self.add_in_partial(uri=uri, params=params, **kwargs)
         except Exception as e:
             self._logger.error(f'{self._kind} creation failed as {e}')
-            container_logs = Dockerizer.logs(container.id)
-            if container_logs and isinstance(
-                e, (PartialDaemon400Exception, PartialDaemonConnectionException)
-            ):
-                self._logger.debug(
-                    f'error logs from partial daemon: \n {container_logs}'
-                )
-                if e.message and isinstance(e.message, list):
-                    e.message += container_logs.split('\n')
-                elif e.message and isinstance(e.message, str):
-                    e.message += container_logs
+            if container is not None:
+                container_logs = Dockerizer.logs(container.id)
+                if container_logs and isinstance(
+                    e, (PartialDaemon400Exception, PartialDaemonConnectionException)
+                ):
+                    self._logger.debug(
+                        f'error logs from partial daemon: \n {container_logs}'
+                    )
+                    if e.message and isinstance(e.message, list):
+                        e.message += container_logs.split('\n')
+                    elif e.message and isinstance(e.message, str):
+                        e.message += container_logs
             if id in Dockerizer.containers:
                 self._logger.info(f'removing container {id_cleaner(container.id)}')
                 Dockerizer.rm_container(container.id)
@@ -243,53 +227,20 @@ class ContainerStore(BaseStore):
             workspace_store[workspace_id].metadata.managed_objects.add(id)
             return id
 
-    @BaseStore.dump
-    async def update(
-        self,
-        id: DaemonID,
-        kind: UpdateOperation,
-        dump_path: str,
-        pod_name: str,
-        shards: int = None,
-        **kwargs,
-    ) -> DaemonID:
-        """Update the container in the store
-
-        :param id: id of the container
-        :param kind: type of update command to execute (only rolling_update for now)
-        :param dump_path: the path to which to dump on disk
-        :param pod_name: pod to target with the dump request
-        :param shards: nr of shards to dump
-        :param kwargs: keyword args
-        :raises KeyError: if id doesn't exist in the store
-        :return: id of the container
-        """
-        if id not in self:
-            raise KeyError(f'{colored(id, "red")} not found in store.')
-
-        if id.jtype == IDLiterals.JFLOW:
-            params = {
-                'kind': kind.value,
-                'dump_path': dump_path,
-                'pod_name': pod_name,
-            }
-            params.update({'shards': shards} if shards else {})
-        elif id.jtype == IDLiterals.JPOD:
-            params = {'kind': kind.value, 'dump_path': dump_path}
-        else:
-            self._logger.error(f'update not supported for {id.type} {id}')
-            return id
-
-        uri = self[id].metadata.uri
-        try:
-            object = await self._update(uri, params)
-        except Exception as e:
-            self._logger.error(f'Error while updating the {self._kind.title()}: \n{e}')
-            raise
-        else:
-            self[id].arguments.object = object
-            self._logger.success(f'{colored(id, "green")} is updated successfully')
-            return id
+    def _find_partiald_port(self):
+        exposed_docker_ports = Dockerizer.exposed_ports()
+        partiald_port = random_port()
+        port_assignment_runs = 0
+        while (
+            partiald_port in exposed_docker_ports
+            or partiald_port in self._exposed_ports
+        ):
+            if port_assignment_runs >= 2 ** 16:
+                raise OSError('No available ports to new container')
+            partiald_port = random_port()
+            port_assignment_runs += 1
+        self._exposed_ports.add(partiald_port)
+        return partiald_port
 
     @BaseStore.dump
     async def delete(self, id: DaemonID, **kwargs) -> None:
@@ -304,14 +255,14 @@ class ContainerStore(BaseStore):
 
         uri = self[id].metadata.uri
         try:
-            await self._delete(uri=uri)
+            await self.delete_in_partial(uri=uri)
         except Exception as e:
-            self._logger.error(f'Error while updating the {self._kind.title()}: \n{e}')
+            self._logger.error(f'Error while deleting the {self._kind.title()}: \n{e}')
             raise
         else:
             workspace_id = self[id].workspace_id
             del self[id]
-            from . import workspace_store
+            from daemon.stores import workspace_store
 
             Dockerizer.rm_container(id)
             workspace_store[workspace_id].metadata.managed_objects.remove(id)
