@@ -60,7 +60,7 @@ elif _sys.version_info >= (3, 8, 0) and _platform.system() == 'Darwin':
 # this is managed by git tag and updated on every release
 # NOTE: this represents the NEXT release version
 
-__version__ = '3.2.3'
+__version__ = '3.2.7'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
@@ -88,7 +88,7 @@ __jina_env__ = (
     'JINA_HUBBLE_REGISTRY',
     'JINA_HUB_CACHE_DIR',
     'JINA_HUB_ROOT',
-    'JINA_K8S_USE_TEST_PIP',
+    'JINA_GATEWAY_IMAGE',
     'JINA_LOG_CONFIG',
     'JINA_LOG_LEVEL',
     'JINA_LOG_NO_COLOR',
