@@ -1,13 +1,12 @@
-from typing import Dict, Union
+from typing import Dict, Union, TYPE_CHECKING
 
-if False:
-    from ...flow.base import BaseFlow
-    from ...executors import BaseExecutor
-    from ...drivers import BaseDriver
+if TYPE_CHECKING:
+    from jina.orchestrate.flow.base import Flow
+    from jina.serve.executors import BaseExecutor
 
 
 class VersionedYAMLParser:
-    """ Flow YAML parser for specific version
+    """Flow YAML parser for specific version
 
     Every :class:`VersionedYAMLParser` must implement two methods and one class attribute:
         - :meth:`parse`: to load data (in :class:`dict`) into a :class:`BaseFlow` or :class:`BaseExecutor` object
@@ -17,18 +16,21 @@ class VersionedYAMLParser:
 
     version = 'legacy'  #: the version number this parser designed for
 
-    def parse(self, cls: type, data: Dict) -> Union['BaseFlow', 'BaseExecutor', 'BaseDriver']:
+    def parse(self, cls: type, data: Dict) -> Union['Flow', 'BaseExecutor']:
         """Return the Flow YAML parser given the syntax version number
 
-        # noqa: DAR401
+
+        .. # noqa: DAR401
         :param cls: target class type to parse into, must be a :class:`JAMLCompatible` type
         :param data: flow yaml file loaded as python dict
         """
         raise NotImplementedError
 
-    def dump(self, data: Union['BaseFlow', 'BaseExecutor', 'BaseDriver']) -> Dict:
+    def dump(self, data: Union['Flow', 'BaseExecutor']) -> Dict:
         """Return the dictionary given a versioned flow object
-        # noqa: DAR401
+
+
+        .. # noqa: DAR401
         :param data: versioned flow object
         """
         raise NotImplementedError
