@@ -1,7 +1,6 @@
 import argparse
 import base64
 import copy
-import itertools
 import json
 import multiprocessing
 import os
@@ -100,22 +99,22 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
         *,
         asyncio: Optional[bool] = False,
         host: Optional[str] = '0.0.0.0',
-        https: Optional[bool] = False,
         port: Optional[int] = None,
         protocol: Optional[str] = 'GRPC',
         proxy: Optional[bool] = False,
         return_responses: Optional[bool] = False,
+        tls: Optional[bool] = False,
         **kwargs,
     ):
         """Create a Flow. Flow is how Jina streamlines and scales Executors. This overloaded method provides arguments from `jina client` CLI.
 
         :param asyncio: If set, then the input and output of this Client work in an asynchronous manner.
         :param host: The host address of the runtime, by default it is 0.0.0.0.
-        :param https: If set, connect to gateway using https
         :param port: The port of the Gateway, which the client should connect to.
         :param protocol: Communication protocol between server and client.
         :param proxy: If set, respect the http_proxy and https_proxy environment variables. otherwise, it will unset these proxy variables before start. gRPC seems to prefer no proxy
         :param return_responses: If set, return results as List of Requests instead of a reduced DocArray.
+        :param tls: If set, connect to gateway using https
 
         .. # noqa: DAR202
         .. # noqa: DAR101
@@ -129,6 +128,7 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
     def __init__(
         self,
         *,
+        compression: Optional[str] = 'NoCompression',
         connection_list: Optional[str] = None,
         cors: Optional[bool] = False,
         default_swagger_ui: Optional[bool] = False,
@@ -175,6 +175,7 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
     ):
         """Create a Flow. Flow is how Jina streamlines and scales Executors. This overloaded method provides arguments from `jina gateway` CLI.
 
+        :param compression: The compression mechanism used when sending requests to Executors. Possibilites are: `NoCompression, Gzip, Deflate`. For more details, check https://grpc.github.io/grpc/python/grpc.html#compression.
         :param connection_list: dictionary JSON with a list of connections to configure
         :param cors: If set, a CORS middleware is added to FastAPI frontend to allow cross-origin access.
         :param default_swagger_ui: If set, the default swagger ui is used for `/docs` endpoint.
@@ -478,11 +479,11 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
         return graph_dict
 
     def _get_k8s_deployments_addresses(
-        self, k8s_namespace: str, k8s_connection_pool: bool
+        self, k8s_namespace: str
     ) -> Dict[str, List[str]]:
         graph_dict = {}
         from jina.orchestrate.deployments.config.helper import to_compatible_name
-        from jina.serve.networking import K8sGrpcConnectionPool
+        from jina.serve.networking import GrpcConnectionPool
 
         for node, v in self._deployment_nodes.items():
             if node == 'gateway':
@@ -495,11 +496,9 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
                     f'{to_compatible_name(v.head_args.name)}.{k8s_namespace}.svc'
                 )
 
-            # we only need hard coded addresses if the k8s connection pool is disabled or if this deployment is external
-            if not k8s_connection_pool or v.external:
-                graph_dict[node] = [
-                    f'{deployment_k8s_address}:{v.head_port if v.external else K8sGrpcConnectionPool.K8S_PORT}'
-                ]
+            graph_dict[node] = [
+                f'{deployment_k8s_address}:{v.head_port if v.external else GrpcConnectionPool.K8S_PORT}'
+            ]
 
         return graph_dict if graph_dict else None
 
@@ -598,6 +597,7 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
     def add(
         self,
         *,
+        compression: Optional[str] = 'NoCompression',
         connection_list: Optional[str] = None,
         disable_reduce: Optional[bool] = False,
         docker_kwargs: Optional[dict] = None,
@@ -643,6 +643,7 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
     ) -> Union['Flow', 'AsyncFlow']:
         """Add an Executor to the current Flow object.
 
+        :param compression: The compression mechanism used when sending requests from the Head to the WorkerRuntimes. Possibilities are `NoCompression, Gzip, Deflate`. For more details, check https://grpc.github.io/grpc/python/grpc.html#compression.
         :param connection_list: dictionary JSON with a list of connections to configure
         :param disable_reduce: Disable the built-in reduce mechanism, set this if the reduction is to be handled by the Executor connected to this Head
         :param docker_kwargs: Dictionary of kwargs arguments that will be passed to Docker SDK when starting the docker '
@@ -1200,8 +1201,6 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
                 self.close()
                 raise RuntimeFailToStart
 
-        success_msg = '[green]🎉 Flow is ready to use![/green]'
-        console.print(success_msg)
         if addr_table:
             print(
                 addr_table
@@ -1496,7 +1495,7 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
         return self._deployment_nodes.items().__iter__()
 
     def _init_table(self):
-        table = Table(title=None, box=None, highlight=True)
+        table = Table(title=None, box=None, highlight=True, show_header=False)
         table.add_column('', justify='right')
         table.add_column('', justify='right')
         table.add_column('', justify='right')
@@ -1505,41 +1504,41 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
         return table
 
     def _get_address_table(self, address_table):
-        address_table.add_row('🔗', 'Protocol: ', f'{self.protocol}')
+        address_table.add_row('🔗', 'Protocol', f'{self.protocol}')
         address_table.add_row(
             '🏠',
-            'Local access: ',
+            'Local access',
             f'[underline]{self.host}:{self.port}[/underline]',
         )
         address_table.add_row(
             '🔒',
-            'Private network: ',
+            'Private network',
             f'[underline]{self.address_private}:{self.port}[/underline]',
         )
 
         if self.address_public:
             address_table.add_row(
                 '🌐',
-                'Public address: ',
+                'Public address',
                 f'[underline]{self.address_public}:{self.port}[/underline]',
             )
 
         if self.protocol == GatewayProtocolType.HTTP:
             address_table.add_row(
                 '💬',
-                'Swagger UI: ',
+                'Swagger UI',
                 f'[underline]http://localhost:{self.port}/docs[/underline]',
             )
 
             address_table.add_row(
                 '📚',
-                'Redoc: ',
+                'Redoc',
                 f'[underline]http://localhost:{self.port}/redoc[/underline]',
             )
             if self.args.expose_graphql_endpoint:
                 address_table.add_row(
                     '💬',
-                    'GraphQL UI: ',
+                    'GraphQL UI',
                     f'[underline][cyan]http://localhost:{self.port}/graphql[/underline][/cyan]',
                 )
 
@@ -1759,17 +1758,11 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
             any_event_loop=True,
         )
 
-    def to_k8s_yaml(
-        self,
-        output_base_path: str,
-        k8s_namespace: Optional[str] = None,
-        k8s_connection_pool: bool = True,
-    ):
+    def to_k8s_yaml(self, output_base_path: str, k8s_namespace: Optional[str] = None):
         """
         Converts the Flow into a set of yaml deployments to deploy in Kubernetes
         :param output_base_path: The base path where to dump all the yaml files
         :param k8s_namespace: The name of the k8s namespace to set for the configurations. If None, the name of the Flow will be used.
-        :param k8s_connection_pool: Boolean indicating wether the kubernetes connection pool should be used inside the Executor Runtimes.
         """
         import yaml
 
@@ -1787,9 +1780,8 @@ class Flow(PostMixin, JAMLCompatible, ExitStack, metaclass=FlowType):
             k8s_deployment = K8sDeploymentConfig(
                 args=v.args,
                 k8s_namespace=k8s_namespace,
-                k8s_connection_pool=k8s_connection_pool,
                 k8s_deployments_addresses=self._get_k8s_deployments_addresses(
-                    k8s_namespace, k8s_connection_pool
+                    k8s_namespace
                 )
                 if node == 'gateway'
                 else None,
