@@ -2,38 +2,17 @@
 import argparse
 import os
 import warnings
-from typing import Tuple, List
+from typing import Tuple, Type
 
 _SHOW_ALL_ARGS = 'JINA_FULL_CLI' in os.environ
 if _SHOW_ALL_ARGS:
     from jina.logging.predefined import default_logger
 
     default_logger.warning(
-        f'Setting {_SHOW_ALL_ARGS} will make remote Peas with sharding not work when using JinaD'
+        f'Setting {_SHOW_ALL_ARGS} will make remote Pods with sharding not work when using JinaD'
     )
 
 
-DEPRECATED_ARGS_MAPPING = {'override_with': 'uses_with'}
-
-
-def warn_unknown_args(unknown_args: List[str]):
-    """Creates warnings for all given arguments.
-
-    :param unknown_args: arguments that are unknown to Jina
-    """
-    for arg in unknown_args:
-        normalized_arg = arg.replace('--', '').replace('-', '_')
-        if normalized_arg in DEPRECATED_ARGS_MAPPING:
-            new_argument = DEPRECATED_ARGS_MAPPING[normalized_arg]
-            if '-' in arg:
-                new_argument = new_argument.replace('_', '-')
-            warnings.warn(
-                f'''Ignored the deprecated argument '{arg}'. Please use '{new_argument}'.'''
-            )
-        else:
-            warnings.warn(f'ignored unknown argument: {arg}')
-
-
 def add_arg_group(parser, title):
     """Add the arguments for a specific group to the parser
 
@@ -61,8 +40,10 @@ class KVAppendAction(argparse.Action):
         :param values: the values to add to the parser
         :param option_string: inherited, not used
         """
-        import json, re
-        from ..helper import parse_arg
+        import json
+        import re
+
+        from jina.helper import parse_arg
 
         d = getattr(args, self.dest) or {}
         for value in values:
@@ -102,18 +83,16 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
 
             # add the heading if the section was non-empty
             if self.heading is not argparse.SUPPRESS and self.heading is not None:
-                from ..helper import colored
+                from jina.helper import colored
 
                 current_indent = self.formatter._current_indent
                 captial_heading = ' '.join(
                     v[0].upper() + v[1:] for v in self.heading.split(' ')
                 )
-                heading = '⚙️  %*s%s\n' % (
+                heading = '%*s%s\n' % (
                     current_indent,
                     '',
-                    colored(
-                        captial_heading, 'cyan', attrs=['underline', 'bold', 'reverse']
-                    ),
+                    colored(f'▮ {captial_heading}', 'cyan', attrs=['bold']),
                 )
             else:
                 heading = ''
@@ -131,7 +110,7 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         help_string = ''
         if '%(default)' not in action.help:
             if action.default is not argparse.SUPPRESS:
-                from ..helper import colored
+                from jina.helper import colored
 
                 defaulting_nargs = [argparse.OPTIONAL, argparse.ZERO_OR_MORE]
                 if isinstance(action, argparse._StoreTrueAction):
@@ -225,7 +204,7 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         else:
             sub_indent = indent
 
-        return (indent, sub_indent)
+        return indent, sub_indent
 
     def _split_paragraphs(self, text):
         """Split text into paragraphs of like-indented lines.
@@ -234,7 +213,8 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         :return: list of paragraphs
         """
 
-        import textwrap, re
+        import re
+        import textwrap
 
         text = textwrap.dedent(text).strip()
         text = re.sub('\n\n[\n]+', '\n\n', text)
@@ -286,3 +266,33 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
 
 
 _chf = _ColoredHelpFormatter
+
+
+class DeprecateAction(argparse.Action):
+    """
+    Action to deprecated an argument in argparse
+    """
+
+    def __call__(self, parser, namespace, values, option_string=None):  # noqa
+        warnings.warn('Argument {self.option_strings} is deprecated and is *ignored*')
+        delattr(namespace, self.dest)
+
+
+def get_deprecation_renamed_action(
+    replacement: str, action: Type[argparse.Action] = argparse.Action
+):
+    """
+    To deprecate an argument when it has been renamed for argparse
+
+    :param replacement: the new argument name
+    :param action: class of the action that you want to overload with the deprecation to keep the old behavior
+    :return: a action class that can
+    """
+
+    class _DeprecateRenamedAction(action):
+        def __call__(self, parser, namespace, values, option_string=None):
+            warnings.warn(
+                f'Argument {self.option_strings} is deprecated, please use {replacement} instead'
+            )
+
+    return _DeprecateRenamedAction
