@@ -1,7 +1,12 @@
 """Argparser module for remote runtime"""
+from argparse import _StoreTrueAction
+
 from jina import __default_host__, helper
-from jina.enums import CompressAlgo
-from jina.parsers.helper import KVAppendAction, add_arg_group
+from jina.parsers.helper import (
+    KVAppendAction,
+    add_arg_group,
+    get_deprecation_renamed_action,
+)
 
 
 def mixin_remote_runtime_parser(parser):
@@ -35,10 +40,19 @@ def mixin_client_gateway_parser(parser):
     )
 
     gp.add_argument(
-        '--https',
+        '--tls',
         action='store_true',
         default=False,
+        help='If set, connect to gateway using tls encryption',
+    )
+
+    gp.add_argument(
+        '--https',
+        action=get_deprecation_renamed_action('--tls', _StoreTrueAction),
+        # action='store_true',
+        default=False,
         help='If set, connect to gateway using https',
+        dest='tls',
     )
 
 
@@ -79,6 +93,14 @@ def mixin_gateway_parser(parser):
         default='{}',
     )
 
+    gp.add_argument(
+        '--compression',
+        type=str,
+        default='NoCompression',
+        help='The compression mechanism used when sending requests to Executors. Possibilites are: `NoCompression, '
+        'Gzip, Deflate`. For more details, check https://grpc.github.io/grpc/python/grpc.html#compression.',
+    )
+
 
 def _add_host(arg_group):
     arg_group.add_argument(
