@@ -1,9 +1,8 @@
 from abc import ABC
 
-from jina.serve.runtimes.gateway.graph.topology_graph import TopologyGraph
-from jina.serve.networking import create_connection_pool
-
+from jina.serve.networking import GrpcConnectionPool
 from jina.serve.runtimes.asyncio import AsyncNewLoopRuntime
+from jina.serve.runtimes.gateway.graph.topology_graph import TopologyGraph
 
 
 class GatewayRuntime(AsyncNewLoopRuntime, ABC):
@@ -24,10 +23,8 @@ class GatewayRuntime(AsyncNewLoopRuntime, ABC):
 
         deployments_addresses = json.loads(self.args.deployments_addresses)
         # add the connections needed
-        self._connection_pool = create_connection_pool(
-            logger=self.logger,
-            k8s_connection_pool=self.args.k8s_connection_pool,
-            k8s_namespace=self.args.k8s_namespace,
+        self._connection_pool = GrpcConnectionPool(
+            logger=self.logger, compression=self.args.compression
         )
         for deployment_name, addresses in deployments_addresses.items():
             for address in addresses:
